=========
mediabyte
=========


.. image:: https://img.shields.io/pypi/v/mediabyte.svg
        :target: https://pypi.python.org/pypi/mediabyte

.. image:: https://img.shields.io/travis/taext/mediabyte.svg
        :target: https://travis-ci.org/taext/mediabyte

.. image:: https://readthedocs.org/projects/mediabyte/badge/?version=latest
        :target: https://mediabyte.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




A simple and succinct syntax for describing online media.


* Free software: MIT
* Documentation: https://mediabyte.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
